Introduction
============

This theme uses grunt to generate CSS form less, minify JS, and create
template files.

Requirements and installation:
* Install nodejs and npm
* Go to dev folder in this product
* Run `npm install`

Running `grunt` will generate the files for you.

More on installing grunt via npm: http://gruntjs.com/getting-started


Install the following packages using npm install:

font-awesome
grunt-contrib-concat
grunt-contrib-less
grunt-contrib-watch
jquery-placeholder
grunt-contrib-jshint
grunt-contrib-uglify
grunt-remove-logging
twitter-bootstrap-3.0.0
less
